mlpy.learners package
=====================

.. automodule:: mlpy.learners
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mlpy.learners.deep_learning
   mlpy.learners.native
   mlpy.learners.nlp
   mlpy.learners.pytorch
   mlpy.learners.sklearn
   mlpy.learners.unsupervised

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.learners.base
   mlpy.learners.baseline
   mlpy.learners.catboost_wrapper
   mlpy.learners.classification
   mlpy.learners.ensemble
   mlpy.learners.ensemble_advanced
   mlpy.learners.gp_fallback
   mlpy.learners.gradient_boosting
   mlpy.learners.h2o_wrapper
   mlpy.learners.lightgbm_wrapper
   mlpy.learners.regression
   mlpy.learners.sklearn_wrapper
   mlpy.learners.tgpy_wrapper
   mlpy.learners.timeseries
   mlpy.learners.xgboost_wrapper
